@@ -16,6 +16,9 @@ class SSHConn:
         self.password = password
         self.wait_time = wait_time
         
+        self.transport = paramiko.Transport((host, int(port)))
+        self.transport.connect(username=username, password=password)
+        
         self.client = paramiko.SSHClient()
         self.client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
         self.client.connect(host, port, username, password, timeout=3, allow_agent=False, look_for_keys=False)
